@@ -1,6 +1,6 @@
 package scanner
 
-func configureNextJs(sourceDir string) (*SourceInfo, error) {
+func configureNextJs(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	if !checksPass(sourceDir, fileExists("next.config.js")) && !checksPass(sourceDir, dirContains("package.json", "\"next\"")) {
 		return nil, nil
 	}
@@ -13,7 +13,7 @@ func configureNextJs(sourceDir string) (*SourceInfo, error) {
 		Family:       "NextJS",
 		Port:         8080,
 		SkipDatabase: true,
-		Env: env,
+		Env:          env,
 	}
 
 	s.Files = templates("templates/nextjs")
